Index: src/uk/me/parabola/imgfmt/app/net/RoadNetwork.java
===================================================================
--- src/uk/me/parabola/imgfmt/app/net/RoadNetwork.java	(revision 4303)
+++ src/uk/me/parabola/imgfmt/app/net/RoadNetwork.java	(working copy)
@@ -260,6 +260,7 @@
 	public List<RouteCenter> getCenters() {
 		if (centers.isEmpty()){
 			angleChecker.check(nodes);
+			findRoutingIslands();
 			addArcsToMajorRoads();
 			splitCenters();
 		}
@@ -266,6 +267,22 @@
 		return centers;
 	}
 
+	private void findRoutingIslands() {
+		final int visitId = 1;
+//		long t1 = System.currentTimeMillis();
+		for (RouteNode startNode : nodes.values()) {
+			if (startNode.getVisitID() != visitId) {
+				List<RouteNode> connected = new ArrayList<>();
+				startNode.visitNet(visitId, connected);
+				if (connected.size() < 5 && connected.stream().noneMatch(RouteNode::isBoundary))
+					log.error("routing island with only", connected.size(), "routing node(s) at",
+							connected.get(0).getCoord().toDegreeString());
+			}
+		}
+//		long dt = System.currentTimeMillis() - t1;
+//		log.error("island check took", dt, "ms");
+	}
+
 	/**
 	 * add indirect arcs for each road class (in descending order)
 	 */
Index: src/uk/me/parabola/imgfmt/app/net/RouteNode.java
===================================================================
--- src/uk/me/parabola/imgfmt/app/net/RouteNode.java	(revision 4303)
+++ src/uk/me/parabola/imgfmt/app/net/RouteNode.java	(working copy)
@@ -19,8 +19,8 @@
 import java.util.Collections;
 import java.util.HashSet;
 import java.util.Iterator;
+import java.util.LinkedList;
 import java.util.List;
-
 import uk.me.parabola.imgfmt.Utils;
 import uk.me.parabola.imgfmt.app.Coord;
 import uk.me.parabola.imgfmt.app.CoordNode;
@@ -929,5 +929,27 @@
 		return result;
 	}
 
+	/** used to find routing island, but may also be used for other checks */
+	private int visitId;
 	
+	public int getVisitID() {
+		return visitId;
+	}
+
+	public void visitNet(int visitId, List<RouteNode> visited) {
+		if (this.visitId != visitId) {
+			LinkedList<RouteNode> toVisit = new LinkedList<>();
+			toVisit.add(this);
+			while(!toVisit.isEmpty()) {
+				RouteNode n = toVisit.removeFirst();
+				if (n.visitId != visitId) {
+					visited.add(n);
+					for (RouteArc arc : n.arcs) {
+						toVisit.add(arc.getDest());
+					}
+					n.visitId = visitId;
+				}
+			}
+		}
+	}
 }
